wifi: rtw89: pack I/O during bb_sethw to reduce API execution time

Wrap rtw89_chip_bb_sethw() with rtw89_io_pack/unpack so all register
writes during baseband hardware initialization are batched into a single
bus transaction. This reduces API execution time from ~11000 us to
~4000 us on affected platforms.

Signed-off-by: Eric Huang <echuang@realtek.com>
Signed-off-by: Ping-Ke Shih <pkshih@realtek.com>
Link: https://patch.msgid.link/20260712034506.53209-2-pkshih@realtek.com
This commit is contained in:
Eric Huang 2026-07-12 11:44:59 +08:00 • committed by Ping-Ke Shih
commit b45b22bbe9